from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from app.api.routes import auth, users

app = FastAPI(
    title="Enviodeck Authentication API",
    description="Mobile app backend API with user authentication features",
    version="1.0.0",
    openapi_url="/openapi.json",
)

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

app.include_router(auth.router, prefix="/auth", tags=["Authentication"])
app.include_router(users.router, prefix="/user", tags=["Users"])


@app.get("/")
async def root():
    return {
        "title": "Enviodeck Authentication API",
        "documentation": "/docs",
        "health": "/health",
    }


@app.get("/health")
async def health_check():
    return {
        "status": "healthy",
        "service": "Enviodeck Authentication API",
        "version": "1.0.0",
    }
